@@ -1,7 +1,7 @@
 package Config::IOD::Document;
 
-our $DATE = '2015-03-19'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-03-27'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010;
 use strict;
@@ -584,7 +584,7 @@ sub as_string {
                 $line->[COL_K_NL],
             );
         } else {
-            die "BUG: Unknown type '$type' in line $linum";
+            croak "BUG: Unknown type '$type' in line $linum";
         }
     }
 
@@ -608,7 +608,7 @@ Config::IOD::Document - Represent IOD document
 
 =head1 VERSION
 
-This document describes version 0.14 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2015-03-19.
+This document describes version 0.15 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2015-03-27.
 
 =head1 SYNOPSIS
 
